==> gnucash_1.8.10.orig.tar.gz: gnucash-1.8.10/src/report/report-gnome/window-report.h <==
/********************************************************************\
 * window-report.h -- a report window for hypertext report.         *
 * Copyright (C) 1997 Robin D. Clark                                *
 *                                                                  *
 * This program is free software; you can redistribute it and/or    *
 * modify it under the terms of the GNU General Public License as   *
 * published by the Free Software Foundation; either version 2 of   *
 * the License, or (at your option) any later version.              *
 *                                                                  *
 * This program is distributed in the hope that it will be useful,  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    *
 * GNU General Public License for more details.                     *
 *                                                                  *
 * You should have received a copy of the GNU General Public License*
 * along with this program; if not, contact:                        *
 *                                                                  *
 * Free Software Foundation           Voice:  +1-617-542-5942       *
 * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
 * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
\********************************************************************/

#ifndef GNC_REPORT_WINDOW_H
#define GNC_REPORT_WINDOW_H

#include <gnome.h>
#include <guile/gh.h>

#include "gnc-html.h"
#include "gnc-mdi-utils.h"
  
typedef struct gnc_report_window_s gnc_report_window;

/** PROTOTYPES ******************************************************/

gnc_report_window * gnc_report_window_new(GNCMDIChildInfo * mc);
void       gnc_report_window_destroy(gnc_report_window * rep);
void       gnc_report_window_show_report(gnc_report_window * rw, int id);
void       gnc_report_window_reload(gnc_report_window * rw);
gnc_html   * gnc_report_window_get_html(gnc_report_window * rw);
GtkWidget  * gnc_report_window_get_container(gnc_report_window * rw);
SCM        gnc_report_window_get_report(gnc_report_window * rw);

void       gnc_report_window_create_menu(gnc_report_window * report, 
                                         GNCMDIChildInfo * child);
void       gnc_report_window_create_toolbar(gnc_report_window * report, 
                                            GNCMDIChildInfo * child);

GtkWidget * gnc_report_window_default_params_editor(SCM options, SCM report);

void       gnc_main_window_open_report (int report_id, gint toplevel);
void       gnc_main_window_open_report_url (const char * url, gint toplevel);

GnomeMDIChild * gnc_report_window_create_child(const gchar * url);
void       reportWindow(int id);
void       gnc_print_report (int report_id);

void       gnc_report_window_add_edited_report(gnc_report_window * win, 
                                               SCM report);
void       gnc_report_window_remove_edited_report(gnc_report_window * win, 
                                                  SCM report);
void       gnc_report_raise_editor(SCM report);

void       gnc_report_init (void);

#endif

==> gnucash_2.0.2.orig.tar.gz: gnucash-2.0.2/src/report/report-gnome/window-report.h <==
/********************************************************************\
 * window-report.h -- a report window for hypertext report.         *
 * Copyright (C) 1997 Robin D. Clark                                *
 *                                                                  *
 * This program is free software; you can redistribute it and/or    *
 * modify it under the terms of the GNU General Public License as   *
 * published by the Free Software Foundation; either version 2 of   *
 * the License, or (at your option) any later version.              *
 *                                                                  *
 * This program is distributed in the hope that it will be useful,  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    *
 * GNU General Public License for more details.                     *
 *                                                                  *
 * You should have received a copy of the GNU General Public License*
 * along with this program; if not, contact:                        *
 *                                                                  *
 * Free Software Foundation           Voice:  +1-617-542-5942       *
 * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
 * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
\********************************************************************/

#ifndef GNC_REPORT_WINDOW_H
#define GNC_REPORT_WINDOW_H

#include <libguile.h>

#include "gnc-html.h"
#include "qof.h"
  
typedef struct gnc_report_window_s gnc_report_window;

/** PROTOTYPES ******************************************************/

// scm-exposed
GtkWidget * gnc_report_window_default_params_editor(SCM options, SCM report);

// called from multiple places
// [business-gnome/dialog-invoice.c;gnome/window-register.c]; and
// scm-exposed; 3-liner which calls gnc_main_window_open_report after handling busy-cursor.
void       reportWindow(int id);
// window-register; scm-exposed
void       gnc_print_report (int report_id);
// scm-exposed; ~priv
void       gnc_report_raise_editor(SCM report);
// module[/plugin]-init
void       gnc_report_init (void);

void       gnc_reports_show_all (QofSession *session);
#endif
